@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.001004'; # VERSION
+our $VERSION = '0.002000'; # VERSION
 
 use Moose;
-extends 'Business::PaperlessTrans::MessagePart';
+extends 'MooseY::RemoteHelper::MessagePart';
 with 'MooseX::RemoteHelper::CompositeSerialization';
 
 use MooseX::Types::Common::String qw( NonEmptySimpleStr );
@@ -33,7 +33,7 @@ Business::PaperlessTrans::RequestPart::CustomFields - CustomFields
 
 =head1 VERSION
 
-version 0.001004
+version 0.002000
 
 =head1 AUTHOR
 
